@@ -38,7 +38,7 @@ schlatherfull <- function(data, coord, start, cov.mod = "whitmat", ...,
   if (cov.mod == "caugen")
     cov.mod.num <- 5
 
-  param <- c("sill", "range", "smooth")
+  param <- c("nugget", "range", "smooth")
 
   if (cov.mod == "caugen")
     param <- c(param, "smooth2")
@@ -66,7 +66,7 @@ schlatherfull <- function(data, coord, start, cov.mod = "whitmat", ...,
                         paste("as.double(c(", paste(loc.names, collapse = ","), ")), "),
                         paste("as.double(c(", paste(scale.names, collapse = ","), ")), "),
                         paste("as.double(c(", paste(shape.names, collapse = ","), ")), "),
-                        "as.double(sill), as.double(range), as.double(smooth), as.double(smooth2), fit.marge, dns = double(1), PACKAGE = 'SpatialExtremes')$dns"))
+                        "as.double(nugget), as.double(range), as.double(smooth), as.double(smooth2), fit.marge, dns = double(1), PACKAGE = 'SpatialExtremes')$dns"))
 
   fixed.param <- list(...)[names(list(...)) %in% param]
 
@@ -259,12 +259,12 @@ schlatherfull <- function(data, coord, start, cov.mod = "whitmat", ...,
   }
 
   if (cov.mod == "caugen")
-    cov.fun <-  covariance(sill = param["sill"], range = param["range"],
+    cov.fun <-  covariance(nugget = param["nugget"], sill = 1 - param["nugget"], range = param["range"],
                            smooth = param["smooth"], smooth2 = param["smooth2"],
                            cov.mod = cov.mod, plot = FALSE)
 
   else
-    cov.fun <-  covariance(sill = param["sill"], range = param["range"],
+    cov.fun <-  covariance(nugget = param["nugget"], sill = 1 - param["nugget"], range = param["range"],
                            smooth = param["smooth"], cov.mod = cov.mod,
                            plot = FALSE)
 
@@ -386,7 +386,7 @@ schlatherform <- function(data, coord, cov.mod, loc.form, scale.form, shape.form
   scale.names <- paste("scaleCoeff", 1:n.scalecoeff, sep="")
   shape.names <- paste("shapeCoeff", 1:n.shapecoeff, sep="")
 
-  param <- c("sill", "range", "smooth")
+  param <- c("nugget", "range", "smooth")
 
   if (cov.mod == "caugen")
     param <- c(param, "smooth2")
@@ -468,7 +468,7 @@ as.double(temp.penalty.shape),",
                         paste("as.double(c(", paste(temp.names.loc, collapse = ","), ")), "),
                         paste("as.double(c(", paste(temp.names.scale, collapse = ","), ")), "),
                         paste("as.double(c(", paste(temp.names.shape, collapse = ","), ")), "),
-                        "as.double(sill), as.double(range), as.double(smooth), as.double(smooth2),
+                        "as.double(nugget), as.double(range), as.double(smooth), as.double(smooth2),
 dns = double(1), PACKAGE = 'SpatialExtremes')$dns"))
 
   ##Define the formal arguments of the function
@@ -669,12 +669,12 @@ dns = double(1), PACKAGE = 'SpatialExtremes')$dns"))
   }
 
   if (cov.mod == "caugen")
-    cov.fun <- covariance(sill = param["sill"], range = param["range"],
+    cov.fun <- covariance(nugget = param["nugget"], sill = 1 - param["nugget"], range = param["range"],
                           smooth = param["smooth"], smooth2 = param["smooth2"],
                           cov.mod = cov.mod, plot = FALSE)
 
   else
-    cov.fun <- covariance(sill = param["sill"], range = param["range"],
+    cov.fun <- covariance(nugget = param["nugget"], sill = 1- param["nugget"], range = param["range"],
                           smooth = param["smooth"], cov.mod = cov.mod, plot = FALSE)
 
   ext.coeff <- function(h)
