@@ -1,13 +1,12 @@
 #include "header.h"
 
-double whittleMatern(double *dist, int n, double sill, double range,
+double whittleMatern(double *dist, int n, double nugget, double sill, double range,
 		     double smooth, double *rho){
 
   //This function computes the whittle-matern covariance function
   //between each pair of locations.
   //When ans != 0.0, the whittle-matern parameters are ill-defined.
 
-  int i;
   const double cst = sill * R_pow(2, 1 - smooth) / gammafn(smooth),
     irange = 1 / range;
 
@@ -26,11 +25,14 @@ double whittleMatern(double *dist, int n, double sill, double range,
   if (sill <= 0)
     return (1 - sill) * (1 - sill) * MINF;
 
-  for (i=n;i--;){
+  if (nugget < 0)
+    return (1 - nugget) * (1 - nugget) * MINF;
+
+  for (int i=0;i<n;i++){
     double cst2 = dist[i] * irange;
 
     if (cst2 == 0)
-      rho[i] = sill;
+      rho[i] = sill + nugget;
 
     else
       rho[i] = cst * R_pow(cst2, smooth) * bessel_k(cst2, smooth, 1);
@@ -39,14 +41,13 @@ double whittleMatern(double *dist, int n, double sill, double range,
   return 0.0;
 }
 
-double cauchy(double *dist, int n, double sill, double range,
+double cauchy(double *dist, int n, double nugget, double sill, double range,
 	      double smooth, double *rho){
 
   //This function computes the cauchy covariance function between each
   //pair of locations.
   //When ans != 0.0, the cauchy parameters are ill-defined.
 
-  int i;
   const double irange2 = 1 / (range * range);
 
   //Some preliminary steps: Valid points?
@@ -62,20 +63,28 @@ double cauchy(double *dist, int n, double sill, double range,
   if (sill <= 0.0)
     return (1 - sill) * (1 - sill) * MINF;
 
-  for (i=n;i--;)
-    rho[i] = sill * R_pow(1 + dist[i] * dist[i] * irange2, -smooth);
+  if (nugget < 0)
+    return (1 - nugget) * (1 - nugget) * MINF;
+
+  for (int i=0;i<n;i++){
+
+    if (dist[i] == 0)
+      rho[i] = nugget + sill;
+
+    else
+      rho[i] = sill * R_pow(1 + dist[i] * dist[i] * irange2, -smooth);
+  }
 
   return 0.0;
 }
 
-double caugen(double *dist, int n, double sill, double range,
+double caugen(double *dist, int n, double nugget, double sill, double range,
 	      double smooth, double smooth2, double *rho){
 
   /*This function computes the generalized cauchy covariance function
     between each pair of locations.  When ans != 0.0, the parameters
     are ill-defined. */
 
-  int i;
   const double irange = 1 / range, ratioSmooth = -smooth / smooth2;
 
   //Some preliminary steps: Valid points?
@@ -94,21 +103,28 @@ double caugen(double *dist, int n, double sill, double range,
   if (sill <= 0)
     return (1 - sill) * (1 - sill) * MINF;
 
-  for (i=n;i--;)
-    rho[i] = sill * R_pow(1 + R_pow(dist[i] * irange, smooth2),
-			  ratioSmooth);
+  if (nugget < 0)
+    return (1 - nugget) * (1 - nugget) * MINF;
+
+  for (int i=0;i<n;i++){
+    if (dist[i] == 0)
+      rho[i] = nugget + sill;
+
+    else
+      rho[i] = sill * R_pow(1 + R_pow(dist[i] * irange, smooth2),
+			    ratioSmooth);
+  }
 
   return 0.0;
 }
 
-double powerExp(double *dist, int n, double sill, double range,
+double powerExp(double *dist, int n, double nugget, double sill, double range,
 		double smooth, double *rho){
 
   //This function computes the powered exponential covariance function
   //between each pair of locations.
   //When ans != 0.0, the powered exponential parameters are ill-defined.
 
-  int i;
   const double irange = 1 / range;
 
   //Some preliminary steps: Valid points?
@@ -121,19 +137,26 @@ double powerExp(double *dist, int n, double sill, double range,
   if (sill <= 0)
     return (1 - sill) * (1 - sill) * MINF;
 
-  for (i=n;i--;)
-    rho[i] = sill * exp(-R_pow(dist[i] * irange, smooth));
+  if (nugget < 0)
+    return (1 - nugget) * (1 - nugget) * MINF;
+
+  for (int i=0;i<n;i++){
+    if (dist[i] == 0)
+      rho[i] = nugget + sill;
+
+    else
+      rho[i] = sill * exp(-R_pow(dist[i] * irange, smooth));
+  }
 
   return 0.0;
 }
 
-double bessel(double *dist, int n, int dim, double sill,
+double bessel(double *dist, int n, int dim, double nugget, double sill,
 	      double range, double smooth, double *rho){
   //This function computes the bessel covariance function
   //between each pair of locations.
   //When ans != 0.0, the powered exponential parameters are ill-defined.
 
-  int i;
   const double irange = 1 / range, cst = sill * R_pow(2, smooth) * gammafn(smooth + 1);
 
   //Some preliminary steps: Valid points?
@@ -150,12 +173,14 @@ double bessel(double *dist, int n, int dim, double sill,
   if (sill <= 0)
     return (1 - sill) * (1 - sill) * MINF;
 
-  for (i=n;i--;){
-    double cst2;
-    cst2 = dist[i] * irange;
+  if (nugget < 0)
+    return (1 - nugget) * (1 - nugget) * MINF;
+
+  for (int i=0;i<n;i++){
+    double cst2 = dist[i] * irange;
 
     if (cst2 == 0)
-      rho[i] = sill;
+      rho[i] = nugget + sill;
 
     else if (cst2 <= 1e5)
       rho[i] = cst * R_pow(cst2, -smooth) * bessel_j(cst2, smooth);
@@ -165,8 +190,8 @@ double bessel(double *dist, int n, int dim, double sill,
       rho[i] = cst * R_pow(cst2, -smooth) * M_SQRT_2dPI *
 	cos(cst2 - smooth * M_PI_2 - M_PI_4);
 
-    if (!R_FINITE(rho[i]))
-      return MINF;
+    /*if (!R_FINITE(rho[i]))
+      return MINF;*/
   }
 
   return 0.0;
@@ -179,7 +204,6 @@ double mahalDistFct(double *distVec, int n, double *cov11,
   //When ans != 0.0, the covariance matrix and/or the mahalanobis
   //distance is ill-defined.
 
-  int i;
   const double det = *cov11 * *cov22 - *cov12 * *cov12,
     idet = 1 / det;
 
@@ -194,7 +218,7 @@ double mahalDistFct(double *distVec, int n, double *cov11,
   if (det <= 0)
     return (1 - det) * (1 - det) * MINF;
 
-  for (i=n;i--;)
+  for (int i=0;i<n;i++)
     mahal[i] = sqrt((*cov11 * distVec[n + i] * distVec[n + i] -
 		     2 * *cov12 * distVec[i] * distVec[n + i] +
 		     *cov22 * distVec[i] * distVec[i]) * idet);
@@ -210,7 +234,6 @@ double mahalDistFct3d(double *distVec, int n, double *cov11,
   //When ans != 0.0, the covariance matrix and/or the mahalanobis
   //distance is ill-defined.
 
-  int i;
   const double det = *cov11 * *cov22 * *cov33 - *cov12 * *cov12 * *cov33 -
     *cov11 * *cov23 * *cov23 + 2 * *cov12 * *cov13 * *cov23 -
     *cov13 * *cov13 * *cov22,
@@ -228,7 +251,7 @@ double mahalDistFct3d(double *distVec, int n, double *cov11,
   if (detMin <= 0)
     return (1 - detMin) * (1 - detMin) * MINF;
 
-  for (i=n;i--;){
+  for (int i=0;i<n;i++){
 
     mahal[i] = ((*cov22 * *cov33 - *cov23 * *cov23) * distVec[i] * distVec[i] +
 		2 * (*cov13 * *cov23 - *cov12 * *cov33) * distVec[i] * distVec[n + i] +
@@ -245,14 +268,13 @@ double mahalDistFct3d(double *distVec, int n, double *cov11,
 }
 
 double geomCovariance(double *dist, int n, int dim, int covmod,
-		      double sigma2, double sigma2Bound, double sill,
+		      double sigma2, double sigma2Bound, double nugget,
 		      double range, double smooth, double smooth2,
 		      double *rho){
 
   //This function computes the geometric gaussian covariance function
   //between each pair of locations.
   //When ans != 0.0, the parameters are ill-defined.
-  int i;
   const double twiceSigma2 = 2 * sigma2;
   double ans = 0.0;
 
@@ -264,80 +286,39 @@ double geomCovariance(double *dist, int n, int dim, int covmod,
 
   switch (covmod){
   case 1:
-    ans = whittleMatern(dist, n, sill, range, smooth, rho);
+    ans = whittleMatern(dist, n, nugget, 1 - nugget, range, smooth, rho);
     break;
   case 2:
-    ans = cauchy(dist, n, sill, range, smooth, rho);
+    ans = cauchy(dist, n, nugget, 1 - nugget, range, smooth, rho);
     break;
   case 3:
-    ans = powerExp(dist, n, sill, range, smooth, rho);
+    ans = powerExp(dist, n, nugget, 1 - nugget, range, smooth, rho);
     break;
   case 4:
-    ans = bessel(dist, n, dim, sill, range, smooth, rho);
+    ans = bessel(dist, n, dim, nugget, 1 - nugget, range, smooth, rho);
     break;
   case 5:
-    ans = caugen(dist, n, sill, range, smooth, smooth2, rho);
+    ans = caugen(dist, n, nugget, 1 - nugget, range, smooth, smooth2, rho);
   }
 
   if (ans != 0.0)
     return ans;
 
-  for (i=n;i--;)
+  for (int i=0;i<n;i++)
     rho[i] = sqrt(twiceSigma2 * (1 - rho[i]));
 
   return ans;
 }
 
-double nsgeomCovariance(double *dist, int nSite, int dim, int covmod,
-			double *sigma2, double sill, double range,
-			double smooth, double smooth2, double *rho){
-
-  int i, j, currentPair = 0;
-  const int nPairs = nSite * (nSite - 1) / 2;
-  double ans = 0.0;
-
-  switch (covmod){
-  case 1:
-    ans = whittleMatern(dist, nPairs, sill, range, smooth, rho);
-    break;
-  case 2:
-    ans = cauchy(dist, nPairs, sill, range, smooth, rho);
-    break;
-  case 3:
-    ans = powerExp(dist, nPairs, sill, range, smooth, rho);
-    break;
-  case 4:
-    ans = bessel(dist, nPairs, dim, sill, range, smooth, rho);
-    break;
-  case 5:
-    ans = caugen(dist, nPairs, sill, range, smooth, smooth2, rho);
-  }
-
-  if (ans != 0.0)
-    return ans;
-
-  for (i=0;i<(nSite-1);i++){
-    for (j=i+1;j<nSite;j++){
-      rho[currentPair] = sqrt(sigma2[i] - 2 * sqrt(sigma2[i] * sigma2[j]) *
-			      rho[currentPair] + sigma2[j]);
-      currentPair++;
-    }
-  }
-
-  return ans;
-}
-
-
 double brownResnick(double *dist, int n, double range, double smooth,
 		    double *rho){
 
-  int i;
   const double halfSmooth = 0.5 * smooth, irange = 1 / range;
 
   if ((smooth <= 0) || (smooth > 2))
     return (smooth - 1) * (smooth - 1) * MINF;
 
-  for (i=n;i--;)
+  for (int i=0;i<n;i++)
     rho[i] = M_SQRT2 * R_pow(dist[i] * irange, halfSmooth);
 
   return 0;
@@ -350,7 +331,7 @@ double fbm(double *coord, double *dist, int dim, int nSite, double sill, double
   fractional Brownian motion.  When ans != 0.0, the parameters are
   ill-defined. */
 
-  int i, j, currentPair = -1;
+  const int nPairs = nSite * (nSite - 1) / 2;
   const double irange = 1 / range;
   double *distOrig;
 
@@ -373,15 +354,15 @@ double fbm(double *coord, double *dist, int dim, int nSite, double sill, double
 
   /* Rmk: 0.5 Var[Z(x)] = \gamma(||x||) as Z(o) = 0, where \gamma is
      the semi-variogram */
-  for (i=nSite;i--;)
+  for (int i=0;i<nSite;i++)
     distOrig[i] = R_pow(distOrig[i] * irange, smooth);
 
-  for (i=0;i<(nSite-1);i++){
-    for (j=i+1;j<nSite;j++){
-      currentPair++;
-      rho[currentPair] = sill * (distOrig[i] + distOrig[j] -
-				 R_pow(dist[currentPair] * irange, smooth));
-    }
+  for (int currentPair=0;currentPair<nPairs;currentPair++){
+    int i, j;
+    getSiteIndex(currentPair, nSite, &i, &j);
+    
+    rho[currentPair] = sill * (distOrig[i] + distOrig[j] -
+			       R_pow(dist[currentPair] * irange, smooth));
   }
 
   return 0;
